/*
 * lib_path.h
 *
 * Copyright 200@, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef lib_path_h
#define lib_path_h


#include <sys/param.h>


#ifndef ASM_FILE


extern int			pathCmpName(const char *name, const char *path, const int count);
extern size_t		pathLen(const char *);
extern int			cmpStrNum(const char *,const char *);
extern int			isLastPath(const char *);
extern const char	*pathGetNext(const char *);
extern void			convertPath(const char *, char *);


#endif


#endif
